@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -273,13 +273,17 @@ namespace KeePass.Forms
 						// msSource.Close();
 
 						Image img = GfxUtil.LoadImage(pb);
+						if(img == null) throw new FormatException();
+
+						int wMax = PwCustomIcon.MaxWidth;
+						int hMax = PwCustomIcon.MaxHeight;
 						MemoryStream ms = new MemoryStream();
-						if((img.Width == 16) && (img.Height == 16))
+						if((img.Width <= wMax) && (img.Height <= hMax))
 							img.Save(ms, ImageFormat.Png);
 						else
 						{
-							// Image imgNew = new Bitmap(img, new Size(16, 16));
-							Bitmap imgSc = UIUtil.CreateScaledImage(img, 16, 16);
+							// Image imgSc = new Bitmap(img, new Size(wMax, hMax));
+							Image imgSc = GfxUtil.ScaleImage(img, wMax, hMax);
 							imgSc.Save(ms, ImageFormat.Png);
 							imgSc.Dispose();
 						}
@@ -425,7 +429,7 @@ namespace KeePass.Forms
 			{
 				PwUuid pwUuid = (lvi.Tag as PwUuid);
 				if(pwUuid == null) { Debug.Assert(false); return; }
-				Image img = m_pwDatabase.GetCustomIcon(pwUuid);
+				Image img = m_pwDatabase.GetCustomIcon(pwUuid, -1, -1);
 				if(img == null) { Debug.Assert(false); return; }
 
 				// string strExt = UrlUtil.GetExtension(strFile);
