@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -91,7 +91,8 @@ namespace KeePass.Forms
 			FontUtil.AssignDefaultBold(m_cbUserAccount);
 
 			Bitmap bmpBig = SystemIcons.Warning.ToBitmap();
-			m_imgAccWarning = UIUtil.CreateScaledImage(bmpBig, 16, 16);
+			m_imgAccWarning = GfxUtil.ScaleImage(bmpBig, DpiUtil.ScaleIntX(16),
+				DpiUtil.ScaleIntY(16), ScaleTransformFlags.UIIcon);
 			bmpBig.Dispose();
 			m_picAccWarning.Image = m_imgAccWarning;
 
@@ -271,11 +272,16 @@ namespace KeePass.Forms
 		{
 			m_icgPassword.Enabled = m_cbPassword.Checked;
 
-			m_btnOpenKeyFile.Enabled = m_btnSaveKeyFile.Enabled =
-				m_cmbKeyFile.Enabled = m_cbKeyFile.Checked;
+			bool bKeyFile = m_cbKeyFile.Checked;
+			m_cmbKeyFile.Enabled = bKeyFile;
 
 			string strKeyFile = m_cmbKeyFile.Text;
 
+			bool bKeyProv = (!strKeyFile.Equals(KPRes.NoKeyFileSpecifiedMeta) &&
+				Program.KeyProviderPool.IsKeyProvider(strKeyFile));
+			m_btnOpenKeyFile.Enabled = m_btnSaveKeyFile.Enabled =
+				(bKeyFile && !bKeyProv);
+
 			if(!m_cbPassword.Checked && !m_cbKeyFile.Checked && !m_cbUserAccount.Checked)
 				m_btnCreate.Enabled = false;
 			else if(m_cbKeyFile.Checked && strKeyFile.Equals(KPRes.NoKeyFileSpecifiedMeta))
@@ -348,8 +354,22 @@ namespace KeePass.Forms
 
 			if(ofd.ShowDialog() == DialogResult.OK)
 			{
-				string str = ofd.FileName;
-				m_cmbKeyFile.Items.Add(str);
+				string strFile = ofd.FileName;
+
+				// try
+				// {
+				//	IOConnectionInfo ioc = IOConnectionInfo.FromPath(strFile);
+				//	if(ioc.IsLocalFile())
+				//	{
+				//		FileInfo fi = new FileInfo(strFile);
+				//		if(fi.Length >= (100 * 1024 * 1024))
+				//		{
+				//		}
+				//	}
+				// }
+				// catch(Exception) { Debug.Assert(false); }
+
+				m_cmbKeyFile.Items.Add(strFile);
 				m_cmbKeyFile.SelectedIndex = m_cmbKeyFile.Items.Count - 1;
 			}
 
