@@ -1,6 +1,6 @@
 ﻿/*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,8 +54,25 @@ namespace KeePass.Forms
 			m_tbAddress.Text = Program.Config.Integration.ProxyAddress;
 			m_tbPort.Text = Program.Config.Integration.ProxyPort;
 
-			m_tbUser.Text = Program.Config.Integration.ProxyUserName;
-			m_tbPassword.Text = Program.Config.Integration.ProxyPassword;
+			string strUserName = Program.Config.Integration.ProxyUserName;
+			string strPassword = Program.Config.Integration.ProxyPassword;
+
+			ProxyAuthType pat = Program.Config.Integration.ProxyAuthType;
+			if(pat == ProxyAuthType.Auto)
+			{
+				if((strUserName.Length > 0) || (strPassword.Length > 0))
+					pat = ProxyAuthType.Manual;
+				else pat = ProxyAuthType.Default;
+			}
+
+			if(pat == ProxyAuthType.None) m_rbAuthNone.Checked = true;
+			else if(pat == ProxyAuthType.Manual) m_rbAuthManual.Checked = true;
+			else m_rbAuthDefault.Checked = true;
+
+			m_tbUser.Text = strUserName;
+			m_tbPassword.Text = strPassword;
+
+			EnableControlsEx();
 		}
 
 		private void OnFormClosed(object sender, FormClosedEventArgs e)
@@ -69,10 +86,15 @@ namespace KeePass.Forms
 			if(m_rbNoProxy.Checked) pst = ProxyServerType.None;
 			else if(m_rbManualProxy.Checked) pst = ProxyServerType.Manual;
 
+			ProxyAuthType pat = ProxyAuthType.Default;
+			if(m_rbAuthNone.Checked) pat = ProxyAuthType.None;
+			else if(m_rbAuthManual.Checked) pat = ProxyAuthType.Manual;
+
 			AceIntegration ace = Program.Config.Integration;
 			ace.ProxyType = pst;
 			ace.ProxyAddress = m_tbAddress.Text;
 			ace.ProxyPort = m_tbPort.Text;
+			ace.ProxyAuthType = pat;
 			ace.ProxyUserName = m_tbUser.Text;
 			ace.ProxyPassword = m_tbPassword.Text;
 
@@ -81,24 +103,42 @@ namespace KeePass.Forms
 
 		private void EnableControlsEx()
 		{
+			Control[] vAddr = new Control[] {
+				m_lblAddress, m_tbAddress, m_lblPort, m_tbPort
+			};
+			Control[] vAuthType = new Control[] {
+				m_rbAuthNone, m_rbAuthDefault, m_rbAuthManual
+			};
+			Control[] vAuthData = new Control[] {
+				m_lblUser, m_tbUser, m_lblPassword, m_tbPassword
+			};
+			List<Control> lAuthAll = new List<Control>(vAuthType);
+			lAuthAll.AddRange(vAuthData);
+
+			bool bAddr = m_rbManualProxy.Checked;
+			foreach(Control cAddr in vAddr) { cAddr.Enabled = bAddr; }
+
 			if(m_rbNoProxy.Checked)
 			{
-				m_tbUser.Enabled = m_tbPassword.Enabled =
-					m_lblUser.Enabled = m_lblPassword.Enabled = false;
+				foreach(Control c in lAuthAll) { c.Enabled = false; }
 				m_grpAuth.Enabled = false;
 			}
 			else
 			{
 				m_grpAuth.Enabled = true;
-				m_tbUser.Enabled = m_tbPassword.Enabled =
-					m_lblUser.Enabled = m_lblPassword.Enabled = true;
+				if(m_rbAuthManual.Checked)
+				{
+					foreach(Control c in lAuthAll) { c.Enabled = true; }
+				}
+				else
+				{
+					foreach(Control cC in vAuthType) { cC.Enabled = true; }
+					foreach(Control cD in vAuthData) { cD.Enabled = false; }
+				}
 			}
 
-			m_lblAddress.Enabled = m_tbAddress.Enabled = m_lblPort.Enabled =
-				m_tbPort.Enabled = m_rbManualProxy.Checked;
-
-			if(!m_rbManualProxy.Checked) m_btnOK.Enabled = true;
-			else m_btnOK.Enabled = (m_tbAddress.Text.Length > 0);
+			// if(!m_rbManualProxy.Checked) m_btnOK.Enabled = true;
+			// else m_btnOK.Enabled = (m_tbAddress.Text.Length > 0);
 		}
 
 		private void OnNoProxyCheckedChanged(object sender, EventArgs e)
@@ -120,5 +160,20 @@ namespace KeePass.Forms
 		{
 			EnableControlsEx();
 		}
+
+		private void OnAuthNoneCheckedChanged(object sender, EventArgs e)
+		{
+			EnableControlsEx();
+		}
+
+		private void OnAuthDefaultCheckedChanged(object sender, EventArgs e)
+		{
+			EnableControlsEx();
+		}
+
+		private void OnAuthManualCheckedChanged(object sender, EventArgs e)
+		{
+			EnableControlsEx();
+		}
 	}
 }
