@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 
 using System;
 using System.Collections.Generic;
+using System.Resources;
 using System.Diagnostics;
 
 using KeePass.App.Configuration;
@@ -122,5 +123,10 @@ namespace KeePass.Plugins
 		{
 			get { return Program.ColumnProviderPool; }
 		}
+
+		public ResourceManager Resources
+		{
+			get { return Properties.Resources.ResourceManager; }
+		}
 	}
 }
