@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2014 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2015 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -65,11 +65,9 @@ namespace KeePass.Util
 			{
 				try
 				{
-					if(NativeMethods.ChangeClipboardChain(m_form.Handle,
-						m_hChain) == false)
-					{
-						Debug.Assert(false);
-					}
+					// Ignore return value (no assert); see documentation
+					// of ChangeClipboardChain
+					NativeMethods.ChangeClipboardChain(m_form.Handle, m_hChain);
 				}
 				catch(Exception) { Debug.Assert(false); }
 
